{{/*
Kafka Steam security configuration for C3
*/}}
{{- define "c3.stream-security" }}
{{- $_ := set $ "kafkaDependency" .Values.dependencies.c3KafkaCluster }}
{{- range $key, $val := splitList "\n" (include "confluent-operator.kafka-client-security" .)  }}
{{- if not (empty $val) }}
{{ printf "confluent.controlcenter.streams.%s" $val }}
{{- end }}
{{- end }}
{{- $_ := unset $ "kafkaDependency" }}
{{- end }}


{{/*
Kafka Stream security configuration for C3
*/}}
{{- define "c3.stream-security-config" }}
{{- $_ := set $ "kafkaDependency" .Values.dependencies.c3KafkaCluster}}
{{- if .Values.global.authorization.rbac.enabled }}
{{- $endpoint :=  (index (split ":" .Values.dependencies.c3KafkaCluster.bootstrapEndpoint) "_0") }}
{{- $tls := .Values.dependencies.c3KafkaCluster.tls.enabled }}
# added to support backward-compatibility with CP 5.5 Image
bootstrap.servers.admin={{ .Values.dependencies.c3KafkaCluster.bootstrapEndpoint }}
 bootstrap.servers={{ printf "%s:9073" $endpoint }}
{{- range $key, $val := splitList "\n" (include "confluent-operator.rbac-sasl-oauth-config" .) }}
{{- if not (empty $val) }}
{{ printf "confluent.controlcenter.streams.%s" $val }}
{{- end }}
{{- end }}
{{- if and (not (empty .Values.tls.cacerts)) $tls }}
confluent.controlcenter.streams.ssl.truststore.location=/tmp/truststore.jks
confluent.controlcenter.streams.ssl.truststore.password=${file:/mnt/secrets/jksPassword.txt:jksPassword}
{{- end }}
{{- else }}
bootstrap.servers={{ .Values.dependencies.c3KafkaCluster.bootstrapEndpoint }}
{{- include "c3.stream-security" . }}
{{- end }}
{{- end }}


{{/*
Configure Consumer Configurations
*/}}
{{- define "confluent-operator.consumer-security-config" }}
{{- range $key, $val := splitList "\n" (include "confluent-operator.kafka-client-security" .) }}
{{- if not (empty $val) }}
{{ printf "consumer.%s" $val }} 
{{- end }}
{{- end }}
{{- end }}

{{/*
Monitoring Kafka Cluster configurations
*/}}
{{- define "c3.monitoring-clusters" }}
{{- if $.Values.dependencies.monitoringKafkaClusters }}
{{- range $index, $value := .Values.dependencies.monitoringKafkaClusters }}
{{- $_ := set $ "kafkaDependency" $value }}
{{- $cluster_name := index (pluck "name" $value) 0 }}
{{- $bootstrapEndpoint := index (pluck "bootstrapEndpoint" $value) 0 }}
{{- if empty $bootstrapEndpoint }}
{{- fail (printf "provide bootstrap-endpoint for cluster [%s]" $cluster_name) }}
{{- end }}
{{ printf "\n# Start monitoring cluster [%s] configurations\n" $cluster_name }}
{{- printf "confluent.controlcenter.kafka.%s.bootstrap.servers=%s" $cluster_name $bootstrapEndpoint }}
{{- range $key, $val := splitList "\n" (include "confluent-operator.kafka-client-security" $)  }}
{{- if not (empty $val) }}
{{- if contains "sasl.jaas.config" $val }}
{{- if and (hasKey $value "username") (hasKey $value "password") }}
{{ printf "confluent.controlcenter.kafka.%s.sasl.jaas.config=org.apache.kafka.common.security.plain.PlainLoginModule required username=\"%s\" password=\"%s\";" $cluster_name (first (pluck "username" $value)) (first (pluck "password" $value)) }}
{{- else }}
{{ printf "confluent.controlcenter.kafka.%s.%s" $cluster_name $val }}
{{- end }}
{{- else }}
{{ printf "confluent.controlcenter.kafka.%s.%s" $cluster_name $val }}
{{- end }}
{{- end }}
{{- end }}
{{- printf "\n# End monitoring cluster [%s] configurations\n" $cluster_name }}
{{- $_ := unset $ "kafkaDependency" }}
{{- end }}
{{- end }}
{{- end }}

{{/*
Kafka  security for source-replicator
*/}}
{{- define "c3.source-replicator" }}
{{- if .Values.dependencies.replicatorMonitoring.enabled }}
{{- $value := set $ "kafkaDependency" .Values.dependencies.replicatorMonitoring.source }}
{{- range $key, $val := splitList "\n" (include "confluent-operator.kafka-client-security" .)  }}
{{- if not (empty $val) }}
{{- if contains "sasl.jaas.config" $val }}
{{- $_ := required "username is required" $value.username }}
{{- $_ := required "password is required" $value.password }}
{{ printf "confluent.controlcenter.kafka.source.sasl.jaas.config=org.apache.kafka.common.security.plain.PlainLoginModule required username=\"%s\" password=\"%s\";" $value.username $value.password }}
{{- else }}
{{ printf "confluent.controlcenter.kafka.source.%s" $val }}
{{- end }}
{{- end }}
{{- end }}
{{- $_ := unset $ "kafkaDependency" }}
{{- end }}
{{- end }}